package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````')P``#0```!$MP```@``!30`(``(
M`"@`'0`<``$``'!4L0``5#$!`%0Q`0!X````>`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``$P``
M`!,````$`````0````$``````````(````"```#0L0``T+$```4`````@```
M`0```-"Q``#0L0$`T+$!`+`"``#H$@``!@````"````"````W+$``-RQ`0#<
ML0$`0`$``$`!```&````!`````0```!(`0``2($``$B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C,```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`"$#T4O1EK2V_%55M/,M/_F`Q_2_80````4````@
M````"@```*`2``@"1A&@@```"%8`<1C""``\#0`5$0``$`(`*`````````!8
M(B`*!`H`1(0'J$`(16!)`(0!/D(\EP`!``@A4(`D"6`,@7A)1%HB0`!```$`
M0AD`0(",P(0``A"0$(,)``@!$)")0$#"28`L0)@`0``@`"`$"8"4@>R.EW;`
M!0`````````&````!P````D````*````````````````````"P````T````/
M````$0`````````2````%````!@`````````&@`````````;````'````!\`
M```@````)````"4````F````*``````````I````*@```"X`````````+P``
M`#`````Q````,@```#,`````````-0`````````Y````.@`````````^````
M```````````_````00```$(`````````0P```$0```!&````2@```$T`````
M````4````%$```!2````4P```````````````````%4`````````````````
M````````5P```%@`````````6@````````!<````7@```&````!A````8@``
M````````````8P```&<`````````:0````````!K`````````&X```!P````
M`````'(```!S````=````'8```!W````>@```%^6DQRC6N^05MN3',..A_\-
M.I<+1^PS.M)1!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB#49-1\(72P`N!2
M=R@N3CWV9J_,9MOW`%X&I(?_`:\TZ+%(G>=39B&:X*<""LY*KO_/WD<MXT?&
M`6QSA<7L/Y`"Q@[@/3]^EGPU;T[>Q8D%D&"8[Q)G24DB`2/YI)V[DQQ\[1$/
MH))H9X;YG(%#1=7L6YH[#T%-G7QQA#"$+57KUJ?=HVM8[Y=YHP!EKPP4XIZB
M`O89VLWCG@4RI87[H6Q@,F+;[>K3[P[(.4`?N8WQ#NG[P\)*(GW_[=Z3'*U+
MX\#9<5@<*]#A(BP.L7,;G]:]8!;)65@[0!_:7TDAP^4_+)@BU&BZXY)\(?_D
M#HJ8W<)N>FGZB]DU5Y.M!&(WX_#!0_+OR-Z%($^;Z'P8WNLB%4]::,G%N9Q`
M,+B"#5$;?5^R`8MOO]I7&W9OXW"]T$M]:@E#UI\BQZ@A8F0'4ZD'D!T"$%%^
MJ9R;8M#Z@NPL]HMK?YI\T)\L_(?PEGSN"U'Y\]O3'>;_,**0=8(-0V9+$%Y?
M=F`%;++-%NI:\3VM.0TI_`VHH^#[2>)7Q!A7DEI2_=+O#RS?_DANQ=\??9`0
MZ2[%F[;(U;)QWZO*GP````````````````````#'!``````````````2````
M#```````````````(````!L``````````````"````#>!``````````````2
M````=@0``.";````````$@```$<#``"0F@```````!(```#>`P``/)H`````
M```2````P@,``!2;````````$@```(("``!PM`$``````"``&`!C!@``>+0!
M``0````1`!@`=0(``(R8````````$@```+L#``#(FP```````!(```!E`@``
MN)D````````2````1P8``)"L``!`````$@`-`"(%``"`M`$``````!``\?]U
M`P``=)L````````2````H`,``/29````````$@```*0%``!DQ```A`<``!(`
M#0`3!```>)H````````2````K````%"8````````$@```'T$``"8F```````
M`!(```#>!0``J+4``"@!```2``T`A@,``&":````````$@```"L$``!,F0``
M`````!(````Q!0``N,0!```````0`/'_2P$``#B;````````$@```/4$``!4
M,0$``````!``\?_(!0``6+```-0````2``T`_`4```R:````````$@```'(&
M``#`NP``I`@``!(`#0"'!0``R)P``$0````2``T```0``$2;````````$@``
M`#X"``"`FP```````!(```"M`P``C)L````````2````<`,``.R;````````
M$@```'L!``#4F````````!(```"0!```@+0!``0````A`!D`+P,``"2:````
M````$@```!T$``!LF@```````!(````V`P``^)L````````2````T`,``.B9
M````````$@```+4#``!TF````````!(```"(`0``O)@````````2````FP``
M`,29````````$@````\%``"`M`$``````!``\?\I`P``2)H````````2````
M3P,``'"9````````$@```!@!``!0FP```````!(```#Y`0``")L````````2
M````D00``("T`0`$````(0`9`#P%``"XQ`$``````!``\?_G````S)H`````
M```2````E`4``*3,```$````$@`-`!<"``#XF````````!(````W!@``J,P`
M`&@````2``T`20(``%2:````````$@```'\&```4LP``"`$``!(`#0"&`@``
M')P````````2``T`G@4``/#1````````$@`.`(\#``"HF@```````!(````Q
M!@``,)@````````2``L`T@```/R:````````$@```/(#```HF0```````!(`
M``#)`P``M)H````````2````(`8``/C1```$````$0`/`!8%``"`M`$`````
M`!``\?]/!```7)L````````2````+P```*R9````````$@```&<$``#DF@``
M`````!(````1!@``?+0!``0````1`!@`6`$``-"9````````$@````,%``#,
M,0$``````!``\?\O!@``Z,L``#0````2``T`G`$``&B8````````$@````H%
M``"XQ`$``````!``\?^1!@``K+D``!0"```2``T`^````.R8````````$@``
M`%X#``#PF@```````!(```!S````!)P````````2````%0,``'R9````````
M$@```%<"```PF@```````!(````&`0``$)P````````2````/`$``!B:````
M````$@```%X```"\FP```````!(```#E`0``0)D````````2````/0```-B:
M````````$@```(\$``"`M`$`!````!$`&0#7`P``!)D````````2````Q0$`
M`!"9````````$@```+H%``#HJ@``5````!(`#0`P!0``N,0!```````0`/'_
M"P0``("8````````$@```,,```#<F0```````!(```"``@``<+0!```````0
M`!@`600``&B;````````$@```*<$``"(M`$`!````!$`&0!I`0``R)@`````
M```2````B@```-2;````````$@```.H%``"0M0``&````!(`#0"@`@``-)D`
M```````2````C0(``"";````````$@```(H$``!<MP``4`(``!(`#0`[!```
M')D````````2````H0$``&29````````$@```#($```LFP```````!(```"K
M`@``D+0!`!,````1`!D`:`8``+C7``!N60``$0`/`.L#````F@```````!(`
M``#E`P``P)H````````2````*@$``)29````````$@```'T#``"PFP``````
M`!(```!O!```B)D````````2````F0(``)R:````````$@```-,!``"DFP``
M`````!(```">!@``'+0``'0!```2``T`0@0``*"9````````$@```*8!``"$
MF@```````!(```"G`P``7)@````````2````)P(``."8````````$@````4&
M``#0M@``C````!(`#0!/````F)L````````2````=@4``"RQ```$````$@`-
M`+(!``"DF````````!(````P`@``6)D````````2`````&QI8G!E<FPN<V\`
M7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T
M97)M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X
M:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M
M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P
M='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])
M<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V
M86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E
M<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%]?
M9&%T85]S=&%R=`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)R97-O;'8N<V\N,@!L:6)N<VPN<V\N,0!L:6)D;"YS
M;RXR`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)P
M=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`
M7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G
M:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE
M;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER
M`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS
M=&%T-C0`7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?
M;65M8W!Y7V-H:P!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI
M;G5X+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB9V-C7W,N<V\N,0!?7V%E
M86)I7W5N=VEN9%]C<'!?<'(P`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`7U]E
M>&ED>%]S=&%R=`!?7V5X:61X7V5N9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B
M<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`"]U<W(O;&EB+W!E<FPU
M+S4N,3`N,"]A<FTM;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`<&%R7V-U<G)E
M;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R
M;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?24]?<W1D:6Y?=7-E9`!X<U]I
M;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!
M0TL`;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=#0U\S
M+C4``````P```````P`"``0``@`"``$``0````(````!``$``@`"``$``@``
M``(``0`"``(``0````$``0`"``$``0`"`````@`"`````@`$``(`!``"``(`
M``````$`!``$```````"``$````!`````0````$``0`!``(``0````(``@`!
M``$``@````(``0````$``0````$``0````(````$``````````````````(`
M`@````$``0`"`````0`"``4```````$```````$``@`"``(````!``(``@``
M``(``@`"`````0`"`````@````$````!```````!``$`F00``!`````@````
M%&EI#0``!0"K!@````````$``0`%`P``$````"`````4:6D-```$`*L&````
M`````0`!`+D$```0````(````%4F>0L```,`M08````````!``$`5`,``!``
M````````%&EI#0```@"K!@```````&RT`0`5`@``@+0!`!17``"(M`$`%&``
M`)"T`0`4:@``*+,!`!84```LLP$`%G8``#"S`0`62@``-+,!`!8J```XLP$`
M%EP``#RS`0`6"P``0+,!`!85``!$LP$`%GL``$BS`0`6`@``3+,!`!8K``!0
MLP$`%F$``%2S`0`6)```6+,!`!9W``!<LP$`%DT``&"S`0`6-@``9+,!`!98
M``!HLP$`%ED``&RS`0`69P``<+,!`!8_``!TLP$`%F0``'BS`0`650``?+,!
M`!88``"`LP$`%GP``(2S`0`6:```B+,!`!8O``",LP$`%E```)"S`0`6<```
ME+,!`!9N``"8LP$`%G0``)RS`0`61```H+,!`!8-``"DLP$`%BP``*BS`0`6
M1P``K+,!`!9=``"PLP$`%BD``+2S`0`6$0``N+,!`!9L``"\LP$`%AT``,"S
M`0`64P``Q+,!`!8F``#(LP$`%E$``,RS`0`6!P``T+,!`!8N``#4LP$`%C@`
M`-BS`0`6%P``W+,!`!8G``#@LP$`%A,``.2S`0`6=0``Z+,!`!8&``#LLP$`
M%G$``/"S`0`6/```]+,!`!9```#XLP$`%FT``/RS`0`6-````+0!`!96```$
MM`$`%D4```BT`0`63@``#+0!`!8^```0M`$`%C$``!2T`0`6"```&+0!`!9E
M```<M`$`%FD``""T`0`6&@``)+0!`!8@```HM`$`%C```"RT`0`60P``,+0!
M`!9?```TM`$`%A```#BT`0`6(0``/+0!`!8B``!`M`$`%GD``$2T`0`6<@``
M2+0!`!9O``!,M`$`%E0``%"T`0`6#```5+0!`!9B``!8M`$`%@4``%RT`0`6
M(P``8+0!`!8H``!DM`$`%D\``&BT`0`64@``$$`MZ0<!`.L0@+WH!.`MY03@
MG^4.X(_@"/"^Y=`:`0``QH_B$<J,XM#ZO.4`QH_B$<J,XLCZO.4`QH_B$<J,
MXL#ZO.4`QH_B$<J,XKCZO.4`QH_B$<J,XK#ZO.4`QH_B$<J,XJCZO.4`QH_B
M$<J,XJ#ZO.4`QH_B$<J,XICZO.4`QH_B$<J,XI#ZO.4`QH_B$<J,XHCZO.4`
MQH_B$<J,XH#ZO.4`QH_B$<J,XGCZO.4`QH_B$<J,XG#ZO.4`QH_B$<J,XFCZ
MO.4`QH_B$<J,XF#ZO.4`QH_B$<J,XECZO.4`QH_B$<J,XE#ZO.4`QH_B$<J,
MXDCZO.4`QH_B$<J,XD#ZO.4`QH_B$<J,XCCZO.4`QH_B$<J,XC#ZO.4`QH_B
M$<J,XBCZO.4`QH_B$<J,XB#ZO.4`QH_B$<J,XACZO.4`QH_B$<J,XA#ZO.4`
MQH_B$<J,X@CZO.4`QH_B$<J,X@#ZO.4`QH_B$<J,XOCYO.4`QH_B$<J,XO#Y
MO.4`QH_B$<J,XNCYO.4`QH_B$<J,XN#YO.4`QH_B$<J,XMCYO.4`QH_B$<J,
MXM#YO.4`QH_B$<J,XLCYO.4`QH_B$<J,XL#YO.4`QH_B$<J,XKCYO.4`QH_B
M$<J,XK#YO.4`QH_B$<J,XJCYO.4`QH_B$<J,XJ#YO.4`QH_B$<J,XICYO.4`
MQH_B$<J,XI#YO.4`QH_B$<J,XHCYO.4`QH_B$<J,XH#YO.4`QH_B$<J,XGCY
MO.4`QH_B$<J,XG#YO.4`QH_B$<J,XFCYO.4`QH_B$<J,XF#YO.4`QH_B$<J,
MXECYO.4`QH_B$<J,XE#YO.4`QH_B$<J,XDCYO.4`QH_B$<J,XD#YO.4`QH_B
M$<J,XCCYO.4`QH_B$<J,XC#YO.4`QH_B$<J,XBCYO.4`QH_B$<J,XB#YO.4`
MQH_B$<J,XACYO.4`QH_B$<J,XA#YO.4`QH_B$<J,X@CYO.4`QH_B$<J,X@#Y
MO.4`QH_B$<J,XOCXO.4`QH_B$<J,XO#XO.4`QH_B$<J,XNCXO.4`QH_B$<J,
MXN#XO.4`QH_B$<J,XMCXO.4`QH_B$<J,XM#XO.4`QH_B$<J,XLCXO.4`QH_B
M$<J,XL#XO.4`QH_B$<J,XKCXO.4`QH_B$<J,XK#XO.4`QH_B$<J,XJCXO.4`
MQH_B$<J,XJ#XO.4`QH_B$<J,XICXO.4`QH_B$<J,XI#XO.4`QH_B$<J,XHCX
MO.4`QH_B$<J,XH#XO.4`QH_B$<J,XGCXO.4`QH_B$<J,XG#XO.4`QH_B$<J,
MXFCXO.4`QH_B$<J,XF#XO.4`QH_B$<J,XECXO.4`QH_B$<J,XE#XO.4`L*#C
M`."@XP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E$___ZPG__^ND
MS```7+<``*C,```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$.___JM!8!`%`!
M```0,)_E`"#3Y0``4N,!(*`#`"##!1[_+^&CM`$`(`"?Y1!`+>D`,)#E``!3
MXQ"`O0@0,)_E``!3XQ"`O0@S_R_A$("]Z-BQ`0```````##0Y0``4^,`$*`!
M"0``"@`0H.$!((#B(`"?Y0``D.4``-#E``!3X0(0H`$!,-+D``!3X_K__QH!
M`*#A'O\OX0#2``#P#RWI!=U-XAQ0@.(`(*#C#3"@X0(0E><!3*#A`<2@X2%,
MA.'_R`SB(12@X0S`A.'_'`'B`1",X0(0@^<$((+B0`!2X_+__QI-3X/B-#"#
MXA00$^4`()/E+,`3Y0(@(>`T$!/E#"`BX`$@(N#B+Z#A#""#Y00P@^($`%/A
M\___&A`0D.4`()WE(`20Z0R`D.5DS)_E!'"=Y0`PD.4"(('@!W"(X`P0H.$%
M@,CA#,""X`4@"N!E0:#AX\V,X`(@B.$!$(?@"'"=Y0(@C.`#8,KA`U`$X"#,
MG^4%4(;A!W"*X`40@>`,8*#A#,"'X`QPG>7B'8'@8E&@X6.!H.$"D,3A`:#(
MX09@A^`((`+@!7`!X`1`AN`'<(KAX<V,X`(@B>$"((S@T*N?Y0?`A.`00)WE
M87&@X100G>7BS8S@"F"@X0J@A.!B0:#A!F"!X`B`BN`$$`S@#*#'X0*0Q>$!
M$(KA!5"&X`<@`N#LC8C@`B")X82KG^4!$(7@&%"=Y0(@B.!L@:#A',"=Y>(=
M@>`*8*#A"J"%X&)1H.$&8(S@!W"*X`7``>`!H,CA`I#$X0S`BN$$0(;@""`"
MX.%]A^`"((GA-*N?Y0S`A.`@0)WE`B"'X&%QH.$D$)WEXLV,X`I@H.$*H(3@
M8D&@X09@@>`(@(K@!!`,X`R@Q^$"D,7A`1"*X050AN`'(`+@[(V(X`(@B>'D
MJI_E`1"%X"A0G>4"((C@;(&@X2S`G>7B'8'@"F"@X0J@A>!B4:#A!F",X`=P
MBN`%P`'@`:#(X0*0Q.$,P(KA!$"&X`@@`N#A?8?@`B")X92JG^4,P(3@,$"=
MY0(@A^!A<:#A-!"=Y>+-C.`*8*#A"J"$X&)!H.$"D,7A!F"!X`B`BN`$$`S@
M#*#'X0<@`N`%4(;@[(V(X#A@G>4"((GA`1"*X4"JG^4"((C@`1"%X&R!H.$\
MP)WEXAV!X`I0H.$*H(;@8F&@X050C.`'<(K@!L`!X`&@R.$"D,3A#,"*X01`
MA>`((`+@_*F?Y0S`A.!`0)WEX7V'X`(@B>$"((?@"G"@X0J@A.!A0:#A1!"=
MY>+-C.!B4:#A`I#&X0=P@>`(@(K@!1`,X`R@Q.$$(`+@`B")X09@A^`!$(KA
M[(V(X`*@B."@N9_E`2"&X$@0G>5LP:#A"V"@X0NP@>#J+8+@:A&@X0J0Q>$$
ML(O@#*`*X$Q`G>4"@,SA`7`"X`J@B>%BD:#AXBV+X`J@@N`&8(3@4""=Y51)
MG^4%4(;@!$""X`%@*>`'<(CA#,"$X`H@)N`'4(7@-+F?Y0(@C.!4P)WEZHV%
MX&I1H.$+8*#A"[",X`G`)>!H<:#AZ"V"X`B`+.!8P)WE!:`GX`9@C.`)8(;@
M`D`JX`$0B^`$0(;@[,B?Y5Q@G>4(@('@8A&@X0>@(>#B+8C@#,"&X.)-A.`%
M8(S@8L&@X0(@*N#`B)_E`B"&X&!@G>4!H"S@"%"@X0B`AN#D+8+@9&&@X0=P
MB.`$@"K@9$"=Y0R@)N`(<(?@!5"$X&B`G>6$2)_E`J`JX`%0A>!B$:#A!$"(
MX.(MA^`*4(7@!J`AX.)=A>`,<(3@8L&@X0(@*N!4B)_E`B"'X&QPG>4!H"S@
M"$"@X0B`A^#E+8+@97&@X09@B.`%@"K@<%"=Y0R@)^`(8(;@!$"%X'2`G>48
M6)_E`J`JX`%`A.!B$:#A!5"(X.(MAN`*0(3@!Z`AX.)-A.`,8(7@8L&@X0(@
M*N#HAY_E`B"&X'A@G>4(4*#A"("&X`=PB.!\@)WE`:`LX&1AH.$%4(C@!(`J
MX.0M@N`,H";@"'"'X+!'G^6`@)WE`J`JX`%0A>!B$:#A!$"(X.(MA^`*4(7@
M!J`AX.)=A>`,<(3@8L&@X0(@*N!\AY_E`B"'X(1PG>4(0*#A"("'X`9@B."(
M@)WE`:`LX&5QH.$$0(C@!8`JX.4M@N`,H"?@"&"&X$17G^6,@)WE`J`JX`%`
MA.!B$:#A"D"$X.(MAN`%4(C@!V`AX.)-A.`,4(7@8L&@X0(@)N`0AY_E`B"%
MX)!0G>4(8*#A"("%X`=PB."4@)WE`:`LX&11H.$&8(C@!(`JX.0M@N`,H"7@
M"'"'X-A&G^68@)WE`J`JX`$0AN!B8:#A!$"(X.(MA^`%@";@"A"!X.(=@>`,
MP(3@8D&@X0(@*.`"((S@H':?Y9S`G>4&H"3@!W",X.$M@N!AP:#A!5"'X`$0
M*N`!4(7@@(:?Y:`0G>4$D(SAXEV%X`B`@>`"D`G@8A&@X61VG^6D()WE!*`,
MX`RP@>$&8(C@!W""X`J`B>$%L`O@#)`!X`1`A^`)H(OA92&@X0B`AN`*H(3@
M+&:?Y:A`G>7E78C@`7""X06P!^`!D`+@!F"$X`S`AN`)@(OA94&@X0B`C.``
M=I_EK,"=Y>5=BN`"8(3A!;`&X`*0!.`'<(S@`1"'X`F@B^%EP:#A"J"!X-1E
MG^6P$)WEY5V(X`1PC.$%L`?@!)`,X`9@@>`"((;@"8"+X641H.$(@(+@J'6?
MY;0@G>7E78K@#&"!X06P!N`,D`'@!W""X`1`A^`)H(OA92&@X0J@A.!\99_E
MN$"=Y>5=B.`!<(+A!;`'X`&0`N`&8(3@#,"&X`F`B^%E0:#A"(",X%!UG^6\
MP)WEY5V*X`)@A.$%L`;@`I`$X`=PC.`!$(?@":"+X67!H.$*H('@)&6?Y<`0
MG>7E78C@!'",X06P!^`$D`S@!F"!X`(@AN`)@(OA91&@X0B`@N#X=)_EQ""=
MY>5=BN`,8('A!;`&X`R0`>`'<(+@!$"'X`F@B^%E(:#A"J"$X,QDG^7(0)WE
MY5V(X`%P@N$%L`?@`9`"X`9@A.`,P(;@"8"+X65!H.$(@(S@H'2?Y<S`G>7E
M78K@`F"$X06P!N`"D`3@!W",X`$0A^`)H(OA9<&@X0J@@>!T9)_ET!"=Y>5=
MB.`$<(SA!;`'X`20#.`&8('@`B"&X`F`B^%E$:#A"(""X$ATG^74()WEY5V*
MX`Q@@>$%L`;@#)`!X`=P@N`$0(?@":"+X64AH.$*H(3@'&2?Y=A`G>7E78C@
M`7""X06P!^`!D`+@!F"$X`S`AN`)@(OA94&@X0B`C.#P<Y_EW,"=Y>5=BN`"
M8(3A!9`&X`*@!.`'<(S@`1"'X`IPB>%EP:#A!W"!X,1CG^7@$)WEY5V(X`2`
MC.$%D`C@!*`,X`9@@>`"((;@"F")X641H.$&8(+@F(.?Y>0@G>7E78?@#'"!
MX060!^`,H`'@"(""X`1`B.`*@(GA92&@X0B`A.!L<Y_EZ$"=Y>5MAN`!4(+A
M`:`"X`:0!>`'<(3@#'"'X`J0B>%F0:#AYLV(X$!3G^4)8(?@['"=Y0*@A.$%
M4(?@#*`*X`*`!.`!$(7@"("*X2!SG^4(@('@\!"=Y>QMAN`'H*#A;,&@X0=P
M@>#T$)WE9E&@X020+.#FC8C@"J"!X`9@*>`,L"7@`B"'X`8@@N`$0(K@^&"=
MY0BP*^#4<I_E:!&@X0M`A.#HC8+@Z)V$X`=PAN#\0)WEN&*?Y06@(>`,P(?@
M!G"@X09@A.!H(:#A!5"&X`B`*N``89WE:4&@X0C`C.#IS8S@!W"&X`)@).`!
M@"+@#&`FX`%PA^`)@"C@!G"'X&RBG^4$89WE;!&@X0A0A>#LS87@"J"&X`10
M(>#L?8?@`J"*X$ABG^5L(:#A#,`EX`A1G>4&@*#A!F"%X`1`AN`,89WE9U&@
MX0S`BN`!D"+@Y\V,X`B`AN`"8"7@!W`IX`&`B.`,8";@!T"$X`"BG^4&<(C@
M$&&=Y6P1H.$*H(;@[,V$X`5`(>#L?8?@`J"*X-QAG^5L(:#A#,`DX!1!G>4&
M@*#A!F"$X`50AN`889WE9T&@X0S`BN`!D"+@Y\V,X`B`AN`"8"3@!W`IX`&`
MB.`,8";@!U"%X)2AG^4&<(C@'&&=Y6P1H.$*H(;@[,V%X`10(>#L?8?@`J"*
MX'!AG^5L(:#A#,`EX"!1G>4&@*#A!F"%X`1`AN`D89WE9U&@X0S`BN`!D"+@
MY\V,X`B`AN`"8"7@!W`IX`&`B.`,8";@!T"$X"BAG^4&<(C@*&&=Y6P1H.$*
MH(;@[,V$X`5`(>#L?8?@`J"*X`1AG^5L(:#A#,`DX"Q!G>4&@*#A!F"$X`50
MAN`P89WE9T&@X0&0(N`,P(K@Y\V,X`*@).`(@(;@!W`IX`=0A>`!@(C@#'`J
MX`=PB."X8)_E-(&=Y6P1H.$&8(C@[,V%X`2`(>`,@"C@`F"&X)A0G^4(8(;@
M.(&=Y>Q]A^!L(:#A!<"@X050B.`\@9WE`:`BX`@P@^!G@:#AYVV&X`S`@^`$
M0(7@`C`HX`=P*N`&,"/@!T"$X`$0C.`#$('@YCV$X#``D.D#P(3@#*"0Y1!`
MD.5F887@"("*X`(@A.#C/8'@`#"`Y1`@@.4$P(#E"&"`Y0R`@.4%W8WB\`^]
MZ![_+^&9>8):H>O9;MR\&X_6P6+*\$<MZ0!P4.(!H*#A`0``&@``H./PA[WH
ME#"?Y0"`D^4``%CC^?__"@!@U^4]`%;C``!6$P!@H`,!8*`3!0``"@=@H.$!
M,/;E/0!3XP``4Q/[__\:!F!GX`!`F.4``%3CZO__"@A0H.$"``#J!$"UY0``
M5./E__\*!`"@X0<0H.$&(*#A-/S_ZP``4./V__\:!C#4YST`4^/S__\:!5!H
MX$51H.$!`(;B`%"*Y0``A.#PA[WH@+0!``3@+>4,T$WB!!"-XLW__^L,T(WB
M`("]Z!!`+>E`0)_E``"4Y0$`<.,0@+T8-`"?Y?+__^L``%#C!@``"@``T.4`
M`%#C`P``"C``4.(!`*`3``"$Y1"`O>@``*#C``"$Y1"`O>ATM`$`>-(``'!`
M+>D(T$WB`%"@X01`C>(X8)_E!@``Z@`PEN4$()WE`C&#X`0@L^4$(`/E``!2
MX_O__QH%`*#A!!"@X:;__^L``%#C\___&@C0C>)P@+WH@+0!`/!!+>D!VDWB
M"-!-XN!`G^4(4(WB!%!%X@`PE.4!RHWB`7"@X0*`H.'(`)_E!1"@X<0@G^4$
M,(SEU_O_ZP!@4.(B``#:`3!&X@,@U><``%+C%0``"@4`H.$O$*#C!B"@X?3[
M_^L``%#C&```"@``H./G^__K``"0Y5O[_^L'$*#A!2"@X08PH.%^^__K`3J-
MX@0@D^4`,)3E`P!2X1,``!H(T(WB`=J-XO"!O>@``%/C!@``"@-@H.$%`*#A
M+Q"@XP8@H.';^__K``!0X^;__QH``*#CSOO_ZP``D.5"^__K!Q"@X0@@H.$D
M^__KYO__ZHC[_^N(M`$`A-(``/\/```00"WI``"@X\'[_^L``)#E-?O_ZP`0
MX.,J^__K``"@X[O[_^L``)#E+_O_ZP`@H.,$$)_E$$"]Z,W[_^K0K```$$`M
MZ0``H..Q^__K``"0Y27[_^O9^O_K`#"0Y0``H.,$0)/EJOO_ZP``D.4>^__K
M\/K_ZP`PT.48,,3E``"@XZ/[_^L``)#E%_O_Z\OZ_^L`,)#E``"@XP1`D^6<
M^__K``"0Y1#[_^OE^O_K`#"0Y0``H..P,=/A_CS#X[HQQ.&3^__K``"0Y0?[
M_^N[^O_K`#"0Y0``H.,$0)/EC/O_ZP``D.4`^__K'!&?Y0`@H.-L^__K'`"$
MY0``H..$^__K``"0Y?CZ_^NL^O_K`#"0Y0``H.,$0)/E??O_ZP``D.7Q^O_K
MP/K_ZP`PD.4@,(3E``"@XW;[_^L``)#EZOK_ZY[Z_^L`,)#E``"@XP1`D^5O
M^__K``"0Y>/Z_^LV^__K`#"0Y0``4^,&```*``"@XV?[_^L``)#EV_K_ZR[[
M_^L`,)#E;#"3Y20PA.4``*#C7_O_ZP!`H.,``)#ETOK_ZX;Z_^L`,)#E!`"@
MX00PD^4H0(/E5OO_ZP``D.7*^O_K?OK_ZP`PD.4$`*#A!#"3Y2Q`@^5.^__K
M``"0Y<+Z_^MV^O_K`#"0Y00`H.$$0)/E1_O_ZP``D.6[^O_K+_O_ZP`PD.4P
M,(3E$("]Z#C5``#P02WI`%!0XG#03>("```*`##5Y0``4^,!```:<-"-XO"!
MO>AM^O_K`&!0X@B`C1+Y__\*!@"@X1_[_^L`0%#B!0"@X20```H3,-3E$T"$
MXBX`4^,E```*NOK_ZP!PH.$$`*#AM_K_ZP``A^`"`(#BX?K_ZZ`PG^4!$*#C
M`"#@XP1`C>4`4(WE`'"@X0W[_^L'$*#A"""@X0,`H./-^O_K`0!PXP<`H.$#
M```*&#"=Y0\Z`^(!"5/C%0``"J3Z_^L'`*#A?OK_ZP8`H.'Z^O_K`$!0X@4`
MH.':__\:!@"@X;;Z_^L%`*#AS/K_Z\K__^H!,-3E``!3X\W__PHN`%/CU/__
M&@(PU.4``%/CR/__"M#__^JY___KZ/__ZI32``!P0"WI`$"@X0``H./T^O_K
M``"0Y6CZ_^N^^O_K!!"@X0`@H.$#`*#CU?K_ZP!04.(!```*``"@XW"`O>CH
M^O_K``"0Y5SZ_^NR^O_K$#"0Y0\Z`^(!"5/C"```"@4`H.'?^O_K``"0Y5/Z
M_^NI^O_K$#"0Y0\Z`^(*"E/C[/__&@0`H.$"$*#C3OK_ZP$`<.(``*`S<("]
MZ/!`+>FX4)_E`MI-XAS03>(`,)7E`BJ-XA0P@N6F^O_K`4J-XAA`A.((0$3B
ME,"?Y0$0H..0()_ED#"?Y0$0C>@$`*#AL?K_ZP``4.,)``"J`$"@XP(ZC>(4
M()/E`#"5Y00`H.$#`%+A%```&AS0C>("VHWB\("]Z!A@C>(,8$;B!`"@X080
MH.$!*J#CD/K_ZP!P4.+M__^Z`0"'XFCZ_^L`0%#BZO__"@80H.$'(*#A//K_
MZP`PH.,',,3GY/__ZF+Z_^N(M`$`J-(```$0``"<T@``R?__ZO!'+>D`,-'E
M`4"@X3T`4^,!0($""-!-X@!@H.$$`*#A)/K_ZP00C>(`<*#A!@"@X2S^_^L`
M4%#B"P``"AWZ_^L``%?A`#"@DU\``(H#(-3G`R#%YP``4N,!,(/B^O__&@``
MH.,(T(WB\(>]Z&B!G^4``)CE`#"0Y0``4^,#4*`!"!"@`P4```H!4(7B!3&0
MYP``4^/[__\:`A"%X@$1H.$X,9_E`""3Y0``4N,'```*:?K_ZP``4.,`H*#A
M``"(Y061H!$,```:``#@X^3__^H!(*#C`0"@X0`@@^4B^O_K`*!0XO?__PH%
MD:#A`!"8Y0D@H.$N^O_K`*"(Y0$PA>(`(*#C`R&*YP10C>4`,-;E/0!3XP``
M4Q,`,*`#`3"@$P,@H`$%```*!B"@X0$P\N4]`%/C``!3$_O__QH"(&;@`@"'
MX@(`@.``4)CE!OK_ZP``4.,)`(7GVO__"G@PG^4$$)WE`""3Y0`PUN4!(9+G
M``!3XP`PPN4)```*/0!3XP,``!H&``#J/0!3XP%@AN(#```*`3#6Y0$PXN4`
M`%/C^/__&CT`H.,"$*#A`#"@XP``PN4#(-3G`2#AY0``4N,!,(/B^O__&J3_
M_^H$D)WE!("?Y0F1H.'+___J@+0!`*2T`0#XP)_E\$<MZ01`C.(HT$WB`'"@
MX0\`M.@04(WB!6"@X0\`IN@#`)3H$$"=Y0,`AN@`,-3E``!3XQ<```H<H)SE
M!@``ZK?Y_^L``%#C%```"@1`M>4`,-3E``!3XPX```H$`*#AU/W_ZP<0H.$`
M8%#B`@``"@`PUN4``%/C\/__&@0`H.$'$*#A8___ZP1`M>4`,-3E``!3X_#_
M_QHHT(WB\(>]Z`<`H.&)^?_K`)"@X0H`H.&&^?_K`("@X08`H.&#^?_K"(")
MX`*`B.(``(C@K/G_ZP$0H.,`(.#C(#"?Y0A@C>6`!(WH`("@X=CY_^L$`*#A
M"!"@X4?__^O3___J`-(``*S2```DP9_E<$`MZ0\`O.@HT$WB#>"@X0\`KN@0
M49_E#P"\Z`!@E>4D8(WE#P"NZ+#`W.&PP,[A^`"?Y;C]_^OT`)_EMOW_Z_``
MG^6T_?_K[`"?Y;+]_^OH`)_EL/W_Z^0`G^6N_?_KX`"?Y:S]_^O<`)_EJOW_
MZ]@`G^6H_?_KU`"?Y8O]_^L-0*#A`!!0X@$```JL`)_E'O__Z[P`G^6$_?_K
M`!!0X@$```JP`)_E&/__ZZP`G^5^_?_K`!!0X@H```IT`)_E$O__ZV0`G^64
M$)_E#___ZR0@G>4`,)7E`P!2X1```!HHT(WB<("]Z'@`G^5O_?_K`!!0X@(`
M``H\`)_E`___Z^___^H1`(3B7!"?Y0H@H../^?_K``!0X^G__QH;$(3B]/__
MZE?Y_^L@T@``B+0!`+32``#$T@``T-(``'C2``#<T@``Z-(``/32```$TP``
M$-,``!S3```PTP``1-,``%#3``"`TP``8-,``'33```00"WI[/C_ZQOY_^L`
M`%#C``"0%1"`O>@00"WI`$!0XAX```H`,-3E``!3XQL```H(^?_K`0!`X@`@
MA.`"`%3A[,"?)0P``"KDP)_E``#4YP`PG.4`$-/E`0!0X0,```H9``#J`##2
MY0``4^$6```:`2!"X@(`5.'Y__\Z!`!2X18``!H``)SE`"#2Y0`PT.4#`%+A
M`0``"A!`O>A?^?_J`@"@XQCY_^L`,%#B'@``"@(@H.-\$)_E$$"]Z.OX_^H`
M,-+E`0!3X>O__PH!($+B`@!4X?G__SH$`%+AZ/__"@``G.4!($+B`@!4X0,`
M`"H`$-+E`##0Y0,`4>'X__\*`B!DX`(P@N(!"E/C`#"@@P4``(H!.J#C!!"@
MX0$@@N(4`)_EF_C_ZPPPG^4#`*#A$("]Z`#2``"$TP``J+0!`'!`+>D`4*#A
MLO__ZP`PT.4``%/C`$"@`0D```I@()_E`$"@X0`@DN4!`(#B`"#2Y0(`4^$`
M0*`!`3#0Y```4^/Z__\:\_S_ZP``4.-P@+T(``!5XW"`O0@`,-7E``!3XW"`
MO0@$`*#A&!"?Y;[X_^L``%3A<("]&`4`H.%P0+WHTOW_Z@#2``"(TP``<$`M
MZ1C03>(4`(WE$!"-Y0P@C>44`(WB$!"-X@P@C>(%^?_K]!&?Y?0!G^4!(*#A
M.04`ZP``H.-I^/_K`$#0Y0``5.,+```:8OC_Z]0AG^4``%#C]`\"Y6X```J'
M^/_K!`"@X??X_^L``)#E:_C_Z\WX_^L`0,#E``"@X_'X_^L``)#E9?C_Z_3X
M_^L`(-#E`#"@X0(@@N,`(,/E``"@X^CX_^L``)#E7/C_Z^OX_^L`,-#E`3"#
MXP`PP.440)WE!4"$X@0`H.'G!0#K`""@XP`PH.,Y!0#K3"&?Y4PQG^5F!@#K
M``!0XT@``!H$`:#AL_C_ZRQ!G^44X)WE`0!>XP#`H.$0`)WE\,\$Y0`PD.4`
M,(SE&#&?Y00PC.44,9_E"#",Y1`QG^4,,(SE!#"@X^P_!.4'``#:#""@X0$P
MH.,#$9#G`3"#X@,`7N$0$(+E!"""XOG__\H#X([B]`\4Y0!0H.,.(*#A##"@
MX<P0G^4`4(WE#E&,Y^SW_^L`4%#B#```"O0/%.5:^/_KL`"?Y7?\_^N,8)_E
M``!0XQ````KT#Q3EV/?_ZRCX_^L%`*#A&-"-XG"`O>AH,)_E9&"?Y?0/$^7N
M]__K`%"@X?0/%.5(^/_K:`"?Y67\_^L``%#C[O__&N@/%N4``%#C`0``"E__
M_^OI___J2`"?Y5S\_^L``%#CZ`\&Y>3__PKW___J-`"?Y6'X_^L!`*#CF_C_
MZZ28``#$F0``G-0!````@/___\]!D-,``+C7``"4TP``',P``,32``#0T@``
MD+0!`/!/+>GL(9_E`=I-XB303>(`,)+E`2J-X@"`H.$<,(+EU`&?Y0%0H.$]
M_/_KS*&?Y0!`FN4$$*#A`'"@X0@`H.$2^/_K`&!0X@P```H($*#AK`&?Y<K]
M_^N8$9_E`3J-XAP@D^4`,)'E"`"@X0,`4N%?```:)-"-X@':C>+PC[WH"`"@
MX>SW_^L<L)KE"Q"@X0`PH.$%`*#A$#"-Y1GX_^L0,)WE`%!0XD$```H@H(WB
M4)&?Y0$P@^($H$KB%#"-Y0`PU>4``%/C"5"@`0``5^,$```*!P"@X040H.%4
M^/_K``!0XRT```H%`*#ATO?_ZP`@U.4`,(7@`1!3Y0(`4>$&```:`6!#Y0(@
M4^4`$-3E`0!`X@(`4>$!,$/B^/__"A0PG>7@$)_E``"#X`$`4.'%___*`1"@
MXP$JH./,,)_E"@"@X0!0C>40`8WI&OC_ZP``H.,G^/_K``"0Y9OW_^OQ]__K
M"A"@X0`@H.$#`*#CU??_ZP``4.,'```:'?C_ZP``D.61]__KY_?_ZQ`PD.4/
M.@/B`@E3XPD```H``*#C"Q"@X=?W_^L``%#C`%"@X<+__QH($*#A1`"?Y7#]
M_^ND___J"@"@X0$0H.."]__K``!0X_#__QH*$*#A(`"?Y6?]_^L*`*#A!?C_
MZP"`H.&8___JP/?_ZXBT`0#0T@```-(``/32``"$TP``_P\``*S2``#P3RWI
M/'B?Y8'<3>)$,(?B--!-XC!8G^4`@*#A#P"3Z!-.C>(`X)7E`FF-XL!`1.)4
MP(?B+.&&Y1->C>(/`(3H#P"\Z-A01>(%X*#A#P"NZ`,`G.ALP(?B`P".Z`<`
MG.@3KHWBL*!*X@<`BNC<!Y_EIOO_ZP!@4.("```*`##6Y0``4^.O`0`:4/[_
MZP!@4.*S`0`*`*#6Y0``6N,*```*@??_ZP8PH.%?$*#C`""0Y8J@H.&Z()+A
M"``2XP`0PP4!H//E``!:X_?__QJ`-Y_E@2R-XC`@@N(#`)+G`##0Y0``4^.!
M`0`*!:"@X0,``.H$`+KE`##0Y0``4^-[`0`*@OO_ZP!04.+X__\*N_S_ZP``
M4./U__\*!0"@X;/W_^L`4%#B\?__"@4`H.$]]__K`$"@X08`H.$Z]__K``"$
MX`$+@.($`(#B8_?_ZP3'G^4`(.#C`#>?Y0"0E^4!$*#C","-Y0!0C>4,8(WE
M!)"-Y0!`H.&+]__KX!:?Y00`H.'%]O_KV`:?Y6#[_^LH0(WE``!0XW`!``H`
M4)CED_?_ZP`0H.$%`*#A#___ZP!04.)I`0`*6_O_ZP`04.(W```*!`"@X1?W
M_^N8%I_EF&:?Y0!0H.,%@*#A`'"@X8P&G^7B_/_K6O?_ZP$0H.,`(.#C?#:?
MY1`"C>@,8(WE"`"-Y00`H.%G]__K#P``ZHGW_^L`,)#E$0!3XQ$``!H'@,3G
M2_?_ZP%0A>(*(*#A`1"@XT`VG^40`HWH#%"-Y1!@C>4(`(WE!`"@X5;W_^L$
M`*#A"!:?Y9#V_^L!`'#C`*"@X>G__PKD!9_E!!"@X;_\_^L$`*#A-OW_Z\R%
MG^4":8WB+"&6Y0`PF.4H`)WE`P!2X6L!`!I-WXWB`MF-XO"/O>@%`*#A[O;_
MZP`P4.(D,(WEPO__"A.^C>(`,.#C$2#@XZ2P2^("4*#C`%"-Y?_V_^LD`)WE
M"Q"@X08@H..S]O_K@6R-XI`UG^4P8(;B`S#6YP``4^,"```:`3#;Y4,`4^,P
M`0`*="6?Y0*)C>*,((CE(B."XB(G@N(B*X+BB"""X@)IC>*0((CE5"6?Y8Q@
MAN*4((CE`GF-XD@EG^4`,*#CF""(Y1S`AN(\)9_EJ'"'X@2@H.&<((CEZ#"(
MY:`PB.6D,(CE+,"-Y20`G>4+$*#A`BF@XXWV_^L`0%#B0@``V@+IC>*@()[E
M`EF-XH0Q@N`#`%+A`AF-@J0@D84.`*"1I""0E>@`E>4!((*"I"Z"X```4..@
M,(7EI""%Y0N`H`$2```*0(!@XBS`G>4(`%3A!("@L0B`H*$``(S@"Q"@X0@@
MH.&5]O_K`NF-XN@PGN4#,(C@0`!3X^@PCN79__\:!@"@X01`:.`(@(O@3O?_
MZS\`5.,/``#:`%"@XP40B.!`(*#C!P"@X83V_^M`4(7B!@"@X43W_^L$,&7@
M/P!3X_7__\I`0$3B)#.@X0$@@^("@XC@`T-$X`0@H.$($*#A1#"@XRP`G>5<
M]O_K`@F-XNA`@.4+$*#A)`"=Y0(IH.-*]O_K`$!0XKS__\HD`)WE?/;_ZP(9
MC>*@4)'E@8R-XJ4AH.$_(`+B`3""XC"`B.*D<)'E`B"(X'\0X.,X`%/C"D"@
MX8@00N6X``#:'`"&XD`@8^(#`(#@`!"@XQCV_^L&`*#A&/?_ZP`PH.,"R8WB
MW#",Y:@PC.6L,(SEL#",Y;0PC.6X,(SEO#",Y<`PC.7$,(SER#",Y<PPC.70
M,(SEU#",Y=@PC.4"B8WB)^B@X2?$H.$E'*#A)2B@X24TH.$&`*#A)VR@X>!@
MR.7AX,CEXL#(Y>-PR.7D$,CEY2#(Y>8PR.7G4,CE]_;_ZP+)C>*0`)SEE!"<
MY2!HH.&8()SE+&"-Y2%LH.&<,)SE-&"-Y2%DH.$\8(WE(FB@X41@C>4C;*#A
MC."<Y2!<H.%,8(WE(V2@X210C>548(WE(%2@X8%LC>(P4(WE&^#&Y2%8H.$N
MS*#A+JB@X2ZTH.$DX)WE.%"-Y1S@QN4B7*#A+."=Y1W@QN4?`,;E,."=Y30`
MG>5`4(WE`HF-XB)4H.$>X,;E(`#&Y3C@G>7L@(CB2%"-Y3P`G>4C6*#A(>#&
MY5!0C>49H,;E&K#&Y1R`C>4B`,;E(Q#&Y43@G>5`$)WE)!#&Y27@QN4G(,;E
M@7R-XD@`C>('0)#H)@#&Y2@0QN4I(,;E*N#&Y2LPQN48P,;E`%"@XQAPA^((
M8*#A````Z@7`U^<&`*#A`5"%X@$0H.,`(.#CZ#&?Y0#`C>4^]O_K%`!5XP)@
MAN+T__\:`,"@XX%<C>(4P,7E!`"@X9S!G^4!$*#C`"#@X[@QG^4$D(WE"("-
MY0S`C>4`0(WE+O;_Z]S^_^J@,9_E@<R-XC#`C.(#H)SG`%#:Y0``5>,$```:
MA?[_Z@2@M.4`,-KE``!3XP<```H*`*#A-?O_ZP``4./W__\*"@"@X2WV_^L`
M`%#C\___"@!0H.%W_O_J`?S_ZP8`H.$F]O_K*`"-Y<;^_^H`4)CED_[_ZC`Q
MG^6!'(WB,!"!X@,`D><`,-#E``!3XPD```KB^?_K``!0XP(```H7]O_K``!0
MXR@``!H$`+KE`##0Y0``4^/U__\:\&"?Y4;^_^H<`(;B`P"`X#@@8^(`$*#C
M7_7_ZU?__^H",-OE00!3X\O^_QH#,-OE0P!3X\C^_QH$,-OE2`!3X\7^_QH%
M,-OE10!3X\+^_QH`,.#C.2#@XR0`G>4`4(WEL/7_ZPL0H.$D`)WE*2"@XV3U
M_^M(P)_E!`"@X0$0H.,`(.#C8#"?Y1`:C>C;]?_KB?[_Z@!@H.$3_O_JI_7_
MZP#2``"(M`$`T-(``"A___^(TP``F-,``.T!``"<UP``@-,``#C5``!XT@``
MO-,``,S3``!<?___`2-%9_[<NIAV5#(0\.'2P[33``"DTP``0'___U!____@
MTP``\$<MZ0``H./,]?_K``"0Y4#U_^M%]?_K`3"@XP`PP.44!Y_ED/G_ZP``
M4.,"```*`##0Y3$`4^/.```*W?O_ZP``H..]]?_K``"0Y3'U_^OH%I_E`2"@
MXPLPH.,,]?_K``!0XS<```H(,)#E_R`#X@D@0N(!`%+C@P$`B@,Y`^(""5/C
MJ`$`&K1FG^4,()#E[#\6Y1B`DN4!`%/C`%"@TR4``-H`4*#C`4"@XP``H..B
M]?_K``"0Y1;U_^L($*#A!2"@X0`PH.,_]?_K`)!0XI8```H`$)GE\"\6Y0@P
MD>4$<9+G`:L3XH,```K_(`/B!`!2XT`!`)H+`%+C.@$`"@P`4N,T`0`*`SD#
MX@()4^-R```*#!"1Y0<`H.&6]?_K``!0XX$``!KL/Q;E`4"$X@0`4^$!4(7B
MV___R@$@0^(%`%+A?0``"@``H.-[]?_K``"0Y>_T_^OH%9_E`2"@XP4PH./*
M]/_K`$!0XAP```H``*#C<?7_ZP``D.7E]/_K"#"4Y?\@`^()($+B`0!2XUT!
M`(H#.0/B`@E3XT(!`!H,,)3EH"6?Y0`0D^6^]/_K"#"4Y?\@`^()($+B`0!2
MXS4!`(H#.0/B`@E3XU(!`!H,,)3E`#"3Y0@PD^4!!1/C:```&@``H.-4]?_K
M``"0Y<CT_^M4%9_E`2"@XP4PH..C]/_K`$!0XA,```I`!9_E%?G_ZP!04.*I
M```*``"@XT;U_^L``)#ENO3_ZP@PE.7_(`/B"2!"X@$`4N,N`0"*`SD#X@()
M4^,?`0`:##"4Y04@H.$`$)/ED_3_Z^!DG^4``*#C-?7_ZP!PH./05)_E``"0
MY:?T_^NL]/_K`'#`Y0<`H.$M]?_K``"0Y:'T_^LV]?_K`'"`Y;@$G^7R^/_K
M!P!0X>@/!N5&```*J!2?Y5#T_^L1`%#C``!0$_"'O0@!`'#C\(>]"/`_%>7H
M+Q7E`!"3Y0`PH.&`!)_E[?3_ZPD@0N(!`%+CB?__BG`$G^5P%)_E(B"@X^;T
M_^L*`*#A#O7_ZP``D.6"]/_K`!"9Y0H@H.$",*#C(_7_ZP`0H.$'`*#A%/7_
MZP``4.-]__\*[#\6Y0$@0^(%`%+A@?__&@$`4^-____:`4"@XP``H./Z]/_K
M`4"$X@``D.5M]/_K"!"@X4?T_^OL/Q;E!`!3X?7__\IS___J`3#0Y0``4^,N
M__\*+/__Z@``H./K]/_K``"0Y5_T_^L(,)3E_R`#X@D@0N(!`%+CNP``B@,Y
M`^(""5/CV```&@PPE.4`$)/EEO3_ZX;__^KP#Q7EXOS_Z^@/!>4(,)3E_R`#
MX@D@0N(!`%+CP```B@,Y`^(""5/CN0``&@PPE.4`$)/E"#"1Y0%;$^)+```*
M_R`#X@0`4N.5``":"P!2XX<```H,`%+C@0``"@,Y`^(""5/C-@``"@P`D>7P
M'Q;E'O3_ZP@PE.7P+Q;E_Q`#X@D00>(!`%'C`&"2Y0!0H.%[``"*`SD#X@()
M4^-8```:##"4Y0`0D^4(,)'E`7L3XD````K_(`/B!`!2XWP``)H+`%+C8@``
M"@P`4N-<```*`SD#X@()4^,"```:"2!"X@$`4N,=``":#""1Y080H.$%,*#A
MJ`*?Y73T_^N=]/_K``"0Y1'T_^L(,)3E_R`#X@D@0N(!`%+C=0``B@,Y`^("
M"5/C6@``&DQBG^4,()3E\#\6Y0`0DN4`()/EB/C_ZU3__^H)($+B`0!2X\7_
M_XI$`I_E1!*?Y6P@H.-;]/_K-`*?Y302G^5N(*#C5_3_ZP4`H.%_]/_K``"0
MY?/S_^L(,)3E_R`#X@D@0N(!`%+C8P``B@,Y`^(""5/C7```&@PPE.4%(*#A
M`!"3Y0(PH..+]/_KK/__Z@<`H.%M]/_K``"0Y>'S_^L(,)3E_R`#X@D@0N(!
M`%+C*0``B@,Y`^(""5/C!@``&@PPE.4'(*#A`!"3Y0(PH.-Y]/_K`""@X;G_
M_^J0`9_EF!&?Y6X@H.,N]/_K@`&?Y8P1G^46((+B*O3_ZW`!G^6`$9_E%R""
MXB;T_^M@`9_E=!&?Y2(@H.,B]/_K4`&?Y5P1G^5B((+B'O3_ZT`!G^50$9_E
M8R""XAKT_^LP`9_E/!&?Y6`@@N(6]/_K(`&?Y3`1G^5A((+B$O3_ZQ`!G^4H
M$9_E;B"@XP[T_^L``9_E"!&?Y3P@H.,*]/_K\`"?Y001G^5L(*#C!O3_Z^``
MG^7T$)_E;B"@XP+T_^O0`)_EZ!"?Y1X@H./^\__KP`"?Y=@0G^4R(*#C^O/_
MZ[``G^6X$)_E,""@X_;S_^N@`)_EN!"?Y3P@H./R\__KD`"?Y9@0G^4X(*#C
M[O/_ZX``G^6($)_E;""@X^KS_^MP`)_EB!"?Y6P@H./F\__K8`"?Y7@0G^4X
M(*#CXO/_ZU``G^5H$)_E,""@X][S_^M``)_E2!"?Y3(@H./:\__K,`"?Y3@0
MG^4>(*#CUO/_Z[32``#HTP``G-0!`'36``!XU@``@-8``/32``#0T@``[0$`
M`+36``#PTP``S-4``(36``",U```G-4``&S5```\U0``)-0``!!`+>D``*#C
MZ_/_ZP``D.5?\__K#!"?Y0P@G^4,,)_E$$"]Z-OS_^H$UP``N)D``"#7```$
MX"WE``"@XPS03>+=\__K``"0Y5'S_^OK___K``"@X]CS_^L``)#E3//_ZQS`
MG^4`X*#C##"@X100G^44()_E`%"-Z%KS_^L,T(WB`("]Z#C5```LUP``9,0`
M`!PPG^4<P)_E!$`MY0,PC^`,0)/@##"3%P0PH`$0`+WHE//_ZI#F``#@'O__
M'O\OX?!'+>E0H)_E4%"?Y0!@H.$!<*#A`H"@X=KR_^M`,)_E!5!JX`,PC^!%
M4;#A"J"#X/"'O0@`0*#C!@"@X0<0H.$((*#A#^"@X03QFN<!0(3B!0!4X??_
M_SKPA[WHM/[__[C^__](Y@```A$AX@```.H",2/B,$`MZ8%`H.&#4*#A!0`T
MX0(`,`$`P)01`L"5$<3*\!'%RO`1>0``"J1*H.&E6G3@`%!EL@8``-H%0(3@
M`B`@X`,P(>```"+@`1`CX`(@(.`#,"'@-@!5XS"`O8@"`1'C`1:@X0'&H.,A
M%HSA`0``"@``<.(`$.'B`@$3XP,VH.$C-HSA`0``"@`@<N(`,./B!0`TX5<`
M``H!0$3B(.!UX@4``+H2SJ#A,@60X``0H>(3#I#@4Q6QX`8``.H@4$7B(.".
MX@$`4N,3SJ#A`L",(U,%D.##'['@`E$!X@(``%H`P'SB``#PX@`0X>(!!E'C
M#@``.@(&4>,&```ZH1"PX6``L.%LP*#A`4"$XH0JH.$!!7+C50``*@(!7..@
MP+`!``"PX@0:H>`%$('A,("]Z(S`L.$``+#@`1"AX`$&$>,!0$3B\___&@``
M,>,`$*`!``"@`Q$_;^$@,(,""S!#XB`@4^('``"J#""2X@0``-H4P(+B#"!B
MXA$,H.$Q$J#A!```ZA0@@N(@P&+2$1*@X3`<@=$0`J#1`T!4X`0:@:`%$(&A
M,("]J`1`X.$?0%3B#0``J@Q`E.(%``#*%$"$XB`@9.(P!*#A$0*`X3$4A>$P
M@+WH#$!DXB`@9.(P`J#A$02`X040H.$P@+WH,02@X040H.$P@+WH```TXP$V
M(^(!%B$"`4"$`@%011*A___JQ,KPX<7*\!$8```*!0`TX0(`,`$#```*`,"4
MX0,0H`$"`*`!,("]Z`,`,>$`$*`3``"@$S"`O1BDRK#A`P``&H``L.$!$+'@
M`A&!(S"`O>@!193B`1:!,C"`O3@"40'B?Q2%XP\6@>,``*#C,("]Z,3*\.$#
M$*`1`@"@$<7*\`$!,*`1`""@$0%&D.$#5I(!`P`Q`0(7@1,P@+WH```PXP`0
MH`,>_R\!,$`MZ0%+H.,R0(3B`%"@XP`0H..=___J```PXP`0H`,>_R\!,$`M
MZ0%+H.,R0(3B`E$0X@``8$(`$*#CD___ZH`@L.'"$:#A81"@X0(.H.'_-!(2
M_P0S$PX3(1(>_R\1```RX_\$,Q,>_R\!,$`MZ0Y-H.,"40'B`A'!XX/__^H!
M()#A'O\O`3!`+>D`4*#C!@``Z@$@D.$>_R\!,$`MZ0)1$>(!``!:``!PX@`0
MX>(!2Z#C,D"$XB'+L.%<__\*`R"@XZS!L.$#(((2K,&PX0,@@A*L(8+@(#!B
MXA##H.$P`J#A$0.`X3$2H.$"0(3@3___Z@#`X.,"``#J`<"@XP```.H!P*#C
M!,`-Y8'`H.',RO#A@\"@X<S*\!$-```*@<"0X8/`D@$#`#$1`@`P`0``H`,>
M_R\!``!PXP,`,>$#`%%1`@!0`<,/H"'##^`Q`0"`XQ[_+^&!P*#AS,KPX0$`
M`!H!QI#A!```&H/`H.',RO#AZ?__&@/&DN'G__\*!``=Y1[_+^$`P*#A`@"@
MX0P@H.$!P*#A`Q"@X0PPH.'____J`4`MZ=7__^L``%#C``!P0P&`O>@(X"WE
M^/__ZP$`H`,``*`3"/"=Y`C@+>7S___K`0"@,P``H",(\)WD".`MY>[__^L!
M`*"3``"@@PCPG>0(X"WEXO__ZP$`H),``*"#"/"=Y`C@+>7=___K`0"@,P``
MH",(\)WD$$`MZ1"`O>@!``(``````$37``!\UP``C-<``)37``"<UP``I-<`
M`#C5``!XUP``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````
M:-<``'#7``"$TP``.-4``$33``!(TP``7-<``-32``!DUP``.-4``$C7``!0
MUP``.-4``%!!4E]#3$5!3@```"]P<F]C+W-E;&8O97AE```E<R\E<P```"]P
M<F]C+R5I+R5S`&5X90`E<R5S)7,``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?5$5-4`````!005)?1$5"54<```!005)?0T%#2$4```!005)?
M4%)/1TY!344`````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,3T)!
M3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT`
M`#$````N````<&%R+0`````M90``+2T``"5S)7,E<R5S`````"5S)7-C86-H
M92TE<R5S```E,#)X`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE
M=25S`````%-94U1%30``05)'5@````!!<W-E<G1I;VX@)7,@9F%I;&5D.B!F
M:6QE(")I;G1E<FYA;',N8R(L(&QI;F4@)60`````*"AS=G1Y<&4I*"AS:'!L
M97`I+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9'5B!\?"`H*'-V='EP
M92DH*'-H<&QE<"DM/G-V7V9L86=S("8@,'AF9BDI(#T](%-6=%]05DQ6```H
M*"@H<VAP;&5P*2T^<W9?9FQA9W,@)B`H,'@P,#`P-#`P,'PP>#`P,#`X,#`P
M*2D@/3T@,'@P,#`P.#`P,"D@)B8@*"@H<W9T>7!E*2@H<VAP;&5P*2T^<W9?
M9FQA9W,@)B`P>&9F*2D@/3T@4U9T7U!61U8@?'P@*"AS=G1Y<&4I*"AS:'!L
M97`I+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9,5BDI`````"@H<W9T
M>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI(#X](%-6=%]05@```"@H
M<W9T>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI("$](%-6=%]05D%6
M`"@H<W9T>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI("$](%-6=%]0
M5DA6`"$H*"@H7W-V:2DM/G-V7V9L86=S("8@*#!X,#`P,#0P,#!\,'@P,#`P
M.#`P,"DI(#T](#!X,#`P,#@P,#`I("8F("@H*'-V='EP92DH*%]S=FDI+3YS
M=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9'5B!\?"`H*'-V='EP92DH*%]S
M=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9,5BDI`!@```!P97)L
M`````#`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG
M('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@``
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``````O````55-%4@````!54T523D%-10````!4
M14U01$E2`%1-4`!#.EQ414U0`"]T;7``````.@```$Q$7TQ)0E)!4EE?4$%4
M2`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42```
M`",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C
M<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE
M("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M
M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U
M<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y
M:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@
M=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@
M("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES
M86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N
M9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@
M8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL
M97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@
M("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U
M<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@
M8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L
M"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@
M("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES
M=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N
M("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X
M:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@
M>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@
M)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P
M?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L
M971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I
M;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD
M(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D
M871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@
M<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&
M2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&
M2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@
M(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R
M>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@
M(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI
M;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@
M)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]
M?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2![
M"B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I
M"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D
M8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@
M("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L
M"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@
M("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@
M("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@
M("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES
M("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L
M87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R
M971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H
M)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@
M("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W
M(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE
M('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E
M<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T
M<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@
M:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X
M96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@
M9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*"B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@
M(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@
M("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?
M<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P
M87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W:&EL92`H0$%2
M1U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@
M("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@(&5V86P@(G5S
M92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*
M("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("1O=70@
M/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@
M("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G
M86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@
M("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@
M)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES
M=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0H*
M("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@6%A8("TM(&%D
M9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@
M*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q
M=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I
M('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N
M;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A
M(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@
M("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*
M("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C
M86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@
M("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!
M4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*
M("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B
M:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@
M("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I
M('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@
M("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@
M("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@
M("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN
M="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@
M5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*
M("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@
M("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@
M<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R
M"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF
M:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@
M("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q
M-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?
M/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@
M("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@
M9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E
M(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@
M:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@
M("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@
M86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S
M>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T
M96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@
M("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O
M=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@
M("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY
M("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N
M($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D
M(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S
M92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@
M("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L
M970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL
M97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L
M8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]
M"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN
M9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M"B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N
M86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@
M)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*
M("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!0
M05(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L
M;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H
M92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@
M("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@
M*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@
M("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G
M<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@
M("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@
M/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q
M=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E
M(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R
M;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@
M("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4[
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!0
M05(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["GT*"B,@
M5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M
M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U
M<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@
M>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@
M("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*
M("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M
M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E
M<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@
M=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@
M/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<
M5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K
M("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@
M("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@
M("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U
M9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@
M8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@
M("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\[
M"B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D
M<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M
M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH
M)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z
M.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M
M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA
M;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@
M("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@
M("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@
M*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@
M("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@
M("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*
M<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@
M:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@
M(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E
M;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@
M?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM0
M05)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@
M("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*
M?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D
M;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@
M("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@
M:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@
M("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@
M("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN
M('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*"C$["@HC;&EN92`Q,#`R"@I?7T5.1%]?"@```'!A<BYP;```
M@;(!@;"PK`<`````B+(!@;"PKP<`````S+(!@;"PKS\`````R&K_?P$````T
M>O]_T/__?RQ[_W^PL*B`-'W_?["L&X!,?O]_L+"J@-Q^_W\!````#(3_?["P
MJ(`<A/]_`0```,B%_W^PJ@6`$(C_?YS__W\<BO]_H/__?[B2_W^PL*Z`-)K_
M?["PJ(!@FO]_`(0"@+2:_W\!`````````)B<``!\G`````````$````!````
M`0```+H"```!````R0(```$```#5`@```0```.`"```!````Z@(```$```#X
M`@```0````4#```!````5`,```$```"9!````0```+D$```/````1`4```P`
M```PF```#0```/#1```9````T+$!`!L````$````&@```-2Q`0`<````!```
M`/7^_V^,@0``!0```%"-```&````@(4```H```"]!@``"P```!`````5````
M``````,````<LP$``@```(@"```4````$0```!<```"HE0``$0```(B5```2
M````(````!,````(````_O__;PB5``#___]O!````/#__V\.E```````````
M````````````````````````````````````````````````````````W+$!
M````````````/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```
M/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\
MF```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8
M```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@`
M`#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```
M/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\
MF```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8```\F```/)@``#R8
M```\F```/)@``#R8```\F`````````````#_____*#$!`&U9``!!)@```&%E
M86)I``$<````!35410`&!`@!"0$2!!0!%0$7`Q@!&@(`1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``1T-#.B`H1TY5*2`T
M+C0N,B`R,#`Y,3`Q.2`H4F5D($AA="`T+C0N,BTU*0``+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N05)-+F5X=&%B`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y
M`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"Y!
M4DTN871T<FEB=71E<P`N8V]M;65N=```````````````````````````````
M````````````````````````````"P````$````"````-($``#0!```3````
M```````````!`````````!,````'`````@```$B!``!(`0``(```````````
M````!``````````A````!P````(```!H@0``:`$``"0```````````````0`
M````````-````/;__V\"````C($``(P!``#T`P``!0`````````$````!```
M`#X````+`````@```("%``"`!0``T`<```8````!````!````!````!&````
M`P````(```!0C0``4`T``+T&``````````````$`````````3@```/___V\"
M````#I0```X4``#Z````!0`````````"`````@```%L```#^__]O`@````B5
M```(%0``@`````8````$````!`````````!J````"0````(```"(E0``B!4`
M`"`````%``````````0````(````<P````D````"````J)4``*@5``"(`@``
M!0````P````$````"````'P````!````!@```#"8```P&```#```````````
M````!`````````!W`````0````8````\F```/!@``.`#``````````````0`
M```$````@@````$````&````')P``!P<``#4-0`````````````$````````
M`(@````!````!@```/#1``#P40``"```````````````!`````````".````
M`0````(```#XT0``^%$``#A?``````````````0`````````E@````$````"
M````,#$!`#"Q```D```````````````$`````````*$````!``!P@@```%0Q
M`0!4L0``>`````T`````````!`````````"L`````0````(```#,,0$`S+$`
M``0```````````````0`````````M@````X````#````T+$!`-"Q```$````
M```````````$`````````,(````/`````P```-2Q`0#4L0``!```````````
M````!`````````#.`````0````,```#8L0$`V+$```0```````````````0`
M````````TP````8````#````W+$!`-RQ``!``0``!@`````````$````"```
M`-P````!`````P```!RS`0`<LP``5`$`````````````!`````0```#A````
M`0````,```!PM`$`<+0``!````````````````0`````````YP````@````#
M````@+0!`("T```X$``````````````(`````````.P````#``!P````````
M``"`M```)P```````````````0````````#\`````0``````````````I[0`
M`)4!``````````````$``````````0````,``````````````#RV```%`0``
M```````````!``````````$````\F```````````#``$````3)@`````````
:``P``0```%"8```````````,```D80`D9```
